/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.*;

import java.net.URI;
import java.util.ArrayList;
import java.util.List;

import static net.sourceforge.xazzle.xhtml.CollectionUtils.newList;
import static org.sourceforge.writexml.Attribute.attribute;

public abstract class BaseXhtmlTag<T extends BaseXhtmlTag<T, U>, U extends XhtmlTag> implements XhtmlTag {
    static final Namespace NAMESPACE = Namespace.namespace(URI.create("http://www.w3.org/1999/xhtml"));
    final TagName tagName;
    final Attributes attributes;
    final List<? extends U> children;

    public BaseXhtmlTag(TagName tagName, Attributes attributes, Iterable<? extends U> children) {
        this.tagName = tagName;
        this.attributes = attributes;
        this.children = newList(children);
    }

    abstract T makeANewOne(Attribute attribute);

    public final T withId(final Id id) {
        return makeANewOne(attribute("id", id, NAMESPACE));
    }

    public final Tag asWriteableToXml() {
        return new Tag(NAMESPACE, tagName, attributes, new ArrayList<WriteableToXml>(children.size()) {{
            for (final XhtmlTag child : children) {
                add(child.asWriteableToXml());
            }
        }});
    }
}
