/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.AttributeValue;
import org.sourceforge.writexml.Attributes;

import static java.util.Arrays.asList;
import static net.sourceforge.xazzle.xhtml.ArchiveUrls.archiveUrls;
import static org.sourceforge.writexml.Attribute.attribute;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class ObjectTag<T extends MayContainFormTag> extends TabbableStandardXhtmlTag<ObjectTag<T>, ObjectElement<? extends T, ?>> implements HeadChild, BodyElement<T, TagScope.InlineExceptAnchor> {
    private static final Attribute DECLARE = attribute("declare", new AttributeValue() {
        public String asString() {
            return "declare";
        }
    }, NAMESPACE);

    private ObjectTag(final Attributes attributes, final Iterable<? extends ObjectElement<? extends T, ?>> children) {
        super(tagName("object"), attributes, children);
    }

    static <T extends MayContainFormTag> ObjectTag<T> objectTag(final ObjectElement<? extends T, ?>... children) {
        return objectTag(asList(children));
    }

    static <T extends MayContainFormTag> ObjectTag<T> objectTag(Iterable<? extends ObjectElement<? extends T, ?>> children) {
        return new ObjectTag<>(attributes(), children);
    }

    ObjectTag<T> makeANewOne(final Attribute attribute) {
        return new ObjectTag<>(attributes.append(attribute), children);
    }

    public ObjectTag<T> withArchives(final ArchiveUrls archiveUrls) {
        final Attribute attribute = attribute("archive", archiveUrls, NAMESPACE);
        return makeANewOne(attribute);
    }

    public ObjectTag<T> withArchives(final ArchiveUrl archiveUrl, final ArchiveUrl... archiveUrls) {
        return withArchives(archiveUrls(archiveUrl, archiveUrls));
    }

    public ObjectTag<T> withClassId(final ClassId codebaseUrl) {
        return makeANewOne(attribute("classid", codebaseUrl, NAMESPACE));
    }

    public ObjectTag<T> withCodebase(final CodebaseUrl codebaseUrl) {
        return makeANewOne(attribute("codebase", codebaseUrl, NAMESPACE));
    }

    public ObjectTag<T> withCodeType(final MimeType mimeType) {
        return makeANewOne(attribute("codetype", mimeType, NAMESPACE));
    }

    public ObjectTag<T> withData(final DataUrl dataUrl) {
        return makeANewOne(attribute("data", dataUrl, NAMESPACE));
    }

    public ObjectTag<T> declaration() {
        return makeANewOne(DECLARE);
    }

    public ObjectTag<T> withHeight(final XhtmlDimension dimension) {
        return makeANewOne(attribute("height", dimension, NAMESPACE));
    }

    public ObjectTag<T> withWidth(final XhtmlDimension dimension) {
        return makeANewOne(attribute("width", dimension, NAMESPACE));
    }

    public ObjectTag<T> withName(final ObjectName objectName) {
        return makeANewOne(attribute("name", objectName, NAMESPACE));
    }

    public ObjectTag<T> withStandbyText(final StandbyText standbyText) {
        return makeANewOne(attribute("standby", standbyText, NAMESPACE));
    }

    public ObjectTag<T> withType(final MimeType mimeType) {
        return makeANewOne(attribute("type", mimeType, NAMESPACE));
    }

    public ObjectTag<T> withClientSideMap(final ClientSideMapUrl clientSideMapUrl) {
        return makeANewOne(attribute("usemap", clientSideMapUrl, NAMESPACE));
    }
}
