/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.Attributes;
import org.sourceforge.writexml.TagName;

import java.util.Collections;

import static java.util.Arrays.asList;
import static org.sourceforge.writexml.Attribute.attribute;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class OptionTag extends SelectTagElement<OptionTag> {
    private OptionTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    static OptionTag optionTag() {
        return new OptionTag(tagName("option"), attributes(), Collections.<XhtmlTag>emptyList());
    }

    static OptionTag optionTag(final XhtmlText text) {
        return new OptionTag(tagName("option"), attributes(), asList(text));
    }

    @Override
    OptionTag makeANewOne(final Attribute attribute) {
        return new OptionTag(tagName, attributes.append(attribute), children);
    }

    public OptionTag selected() {
        return makeANewOne(attribute("selected", new Selected(), NAMESPACE));
    }

    public OptionTag withValue(final Value value) {
        return makeANewOne(attribute("value", value, NAMESPACE));
    }

    public final OptionTag withLabel(final Label label) {
        return makeANewOne(attribute("label", label, NAMESPACE));
    }
}
