/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.AttributeValue;

import static java.util.Arrays.asList;
import static net.sourceforge.xazzle.xhtml.IterableUtils.cons;

public final class Relationships implements AttributeValue {

    private final Iterable<Relationship> relationships;

    private Relationships(final Iterable<Relationship> relationships) {
        this.relationships = relationships;
    }

    public static Relationships relationships(final Relationship relationship, final Relationship... relationships) {
        return new Relationships(cons(relationship, asList(relationships)));
    }

    public String asString() {
        final StringBuilder stringBuilder = new StringBuilder();
        for (Relationship relationship : relationships) {
            if (stringBuilder.length() != 0) {
                stringBuilder.append(" ");
            }
            stringBuilder.append(relationship.asString());
        }
        return stringBuilder.toString();
    }
}
