/*
 * Copyright 2013 Mark Slater
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 *
 * 	http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
 */

package net.sourceforge.xazzle.xhtml;

import org.sourceforge.writexml.Attribute;
import org.sourceforge.writexml.Attributes;
import org.sourceforge.writexml.TagName;

import static java.util.Arrays.asList;
import static org.sourceforge.writexml.Attribute.attribute;
import static org.sourceforge.writexml.Attributes.attributes;
import static org.sourceforge.writexml.TagName.tagName;

public final class TableCellTag<T extends MayContainFormTag> extends TableContentTag<TableCellTag<T>> {
    private TableCellTag(final TagName tagName, final Attributes attributes, final Iterable<? extends XhtmlTag> children) {
        super(tagName, attributes, children);
    }

    static <T extends MayContainFormTag> TableCellTag<T> tableDataTag(final BodyElement<? extends T, ?>... children) {
        return new TableCellTag<>(tagName("td"), attributes(), asList(children));
    }

    static <T extends MayContainFormTag> TableCellTag<T> tableHeaderTag(final BodyElement<? extends T, ?>... children) {
        return new TableCellTag<>(tagName("th"), attributes(), asList(children));
    }

    @Override
    TableCellTag<T> makeANewOne(final Attribute attribute) {
        return new TableCellTag<>(tagName, attributes.append(attribute), children);
    }

    public TableCellTag<T> withAbbreviation(final Abbreviation abbreviation) {
        return makeANewOne(attribute("abbr", abbreviation, NAMESPACE));
    }

    public TableCellTag<T> withAxis(final Axis axis) {
        return makeANewOne(attribute("axis", axis, NAMESPACE));
    }

    public TableCellTag<T> withColumnSpan(final ColumnSpan columnSpan) {
        return makeANewOne(attribute("colspan", columnSpan, NAMESPACE));
    }

    public TableCellTag<T> withHeaderFor(final Ids ids) {
        return makeANewOne(attribute("headers", ids, NAMESPACE));
    }

    public TableCellTag<T> withHeaderFor(final Id id, final Id... ids) {
        return withHeaderFor(Ids.ids(id, ids));
    }

    public TableCellTag<T> withRowSpan(final RowSpan rowSpan) {
        return makeANewOne(attribute("rowspan", rowSpan, NAMESPACE));
    }

    public TableCellTag<T> withScope(final Scope scope) {
        return makeANewOne(attribute("scope", scope, NAMESPACE));
    }

}
